import java.awt.*;
import java.awt.event.*;
import java.util.*;

import javax.swing.*;
import javax.swing.*;

import sv.ui.*;
import sv.kernel.*;

/** 
 * CutCopyManager.java
 * Manage and configure the Cut and Copy
 * @version 0.1
 * @author Byeongseob Ki
 */

class CutCopyManager extends Dialog implements ActionListener {

  // current avaliable CutCopy list
  private List dataList;

  // to access GFPlane class as parent
  protected GFPlane gframe1d = null;

  // to access GFrame2D class as parent
  protected GFrame2D gframe2d = null;

  // to access GFrame3D class as parent
  protected GFrame3D gframe3d = null;


  int mode;

  private boolean cutting;

  public CutCopyManager(Frame gframe, String title, boolean cutting) {
     super(gframe, title, false);
     this.gframe1d = (GFPlane)gframe;
     this.cutting = cutting;
     mode = 1;
     
     // make GUI components
     makeGUI();
         
     pack();
  }


  public CutCopyManager(Frame gframe, String title, 
                                           boolean cutting, int dummy) {
     super(gframe, title, false);
     this.cutting = cutting;
     mode = dummy;

     if (dummy == 2) 
        this.gframe2d = (GFrame2D)gframe;
     else if (dummy == 3)
        this.gframe3d = (GFrame3D)gframe;  
     else {
        System.out.println("Unknown rank data ...");
        return;
     }
     
     // make GUI components
     makeGUI();
         
     pack();
  }


  /**
   * overrided method
   */
  public void actionPerformed(ActionEvent e) {
     String command = e.getActionCommand();

     if (command.equals("  Ok  ")) {                 
        int[] selected = dataList.getSelectedIndexes();
        if (mode == 1)
           gframe1d.multiCutCopy(selected, cutting);
        else if (mode == 2)
           gframe2d.multiCutCopy(selected, cutting);
        else if (mode == 3)
           gframe3d.multiCutCopy(selected, cutting);

        this.dispose();
     } else if (command.equals("Cancel")) {   
        for (int i=0; i<dataList.getItemCount(); i++)
            dataList.deselect(i);
     }
  }

  // make GUI of this class
  private void makeGUI() {
     setLayout(new BorderLayout());

     GridBagLayout gbl = new GridBagLayout();
     GridBagConstraints gbc = new GridBagConstraints();

     // make center part(instruction panel)
     JPanel p = new JPanel();
     p.setLayout(gbl);
     p.setBorder(new TitledBorder("Cut & Copy"));
     Image img = getToolkit().getImage(getClass().getResource("icons/request.gif"));
     
     SimpleCanvas sc = new SimpleCanvas(img);
     sc.setSize(40, 40);

     gbc.gridx = 1;
     gbc.gridy = 1;
     gbl.setConstraints(sc, gbc);
     p.add(sc);

     Panel dummy = new Panel();
     dummy.setLayout(new GridLayout(3, 1));
     dummy.add(new Label("You have to choose the DataSet from the list"));
     dummy.add(new Label("to Cut or Copy because of multiple DataSet. "));

     gbc.gridx = 2;
     gbc.gridy = 1;
     gbl.setConstraints(dummy, gbc);
     p.add(dummy);

     gbc.gridx = 2;
     gbc.gridy = 2;
     gbc.fill = GridBagConstraints.BOTH;
     dataList = new List(5, true);
     dataList.addActionListener(this);
     gbl.setConstraints(dataList, gbc);
     p.add(dataList);

     Enumeration e;
     if (mode == 1)
        for (e=gframe1d.dataSetVector.elements(); e.hasMoreElements();) {
           DataSet1D data = (DataSet1D)e.nextElement();
           dataList.addItem(data.getTitle());
        }
     else if (mode == 2)
        for (e=gframe2d.dataSetVector.elements(); e.hasMoreElements();) {
           DataSet2D data = (DataSet2D)e.nextElement();
           dataList.addItem(data.getTitle());
        }
     else if (mode == 3)
        for (e=gframe3d.dataSetVector.elements(); e.hasMoreElements();) {
           DataSet3D data = (DataSet3D)e.nextElement();
           dataList.addItem(data.getTitle());
        }

     // make lower part(two buttons)
     Panel lowerPanel = new Panel();
     lowerPanel.setLayout(new BorderLayout());
     lowerPanel.setLayout(new FlowLayout(FlowLayout.RIGHT, 5, 5));
     Button okbtn = new Button("  Ok  ");
     okbtn.addActionListener(this);
     lowerPanel.add(okbtn);

     Button cancelbtn = new Button("Cancel");
     cancelbtn.addActionListener(this);
     lowerPanel.add(cancelbtn);

     add("Center", p);
     add("South", lowerPanel);
  }

} // end of class


